From 1053c32d9ecc95ce946bbbf49cccfe800881f9aa Mon Sep 17 00:00:00 2001
From: Zachary T Welch <zw@superlucidity.net>
Date: Fri, 13 Nov 2009 06:03:59 -0800
Subject: jtag_command_container_t -> union jtag_command_container

Remove misleading typedef from union jtag_container.
---
 src/jtag/commands.h | 9 ++++-----
 1 file changed, 4 insertions(+), 5 deletions(-)

diff --git a/src/jtag/commands.h b/src/jtag/commands.h
index 5c274435..150f0336 100644
--- a/src/jtag/commands.h
+++ b/src/jtag/commands.h
@@ -104,8 +104,7 @@ struct sleep_command {
  * Defines a container type that hold a pointer to a JTAG command
  * structure of any defined type.
  */
-typedef union jtag_command_container_u
-{
+union jtag_command_container {
 	struct scan_command*         scan;
 	struct statemove_command*    statemove;
 	struct pathmove_command*     pathmove;
@@ -114,10 +113,10 @@ typedef union jtag_command_container_u
 	struct reset_command*        reset;
 	struct end_state_command*    end_state;
 	struct sleep_command* sleep;
-} jtag_command_container_t;
+};
 
 /**
  * The type of the @c jtag_command_container_u contained by a
  * @c jtag_command_s structure.
  */
 enum jtag_command_type {
@@ -132,7 +131,7 @@ enum jtag_command_type {
 
 typedef struct jtag_command_s
 {
-	jtag_command_container_t cmd;
+	union jtag_command_container cmd;
 	enum jtag_command_type   type;
 	struct jtag_command_s*   next;
 } jtag_command_t;
@@ -114,10 +113,10 @@ typedef union jtag_command_container_u
 
 /**
- * The type of the @c jtag_command_container_u contained by a
+ * The type of the @c jtag_command_container contained by a
  * @c jtag_command_s structure.
  */
-- 
cgit v1.2.3